@@ -37,7 +37,7 @@ namespace KileWidget { class LogMsg; }
 
 class ConfigCodeCompletion : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public: 
    ConfigCodeCompletion(TDEConfig *config, KileWidget::LogMsg *logwidget, TQWidget *parent=0, const char *name=0);
