@@ -130,7 +130,7 @@ IncludeGraphics::IncludeGraphics(TQWidget *parent, const TQString &startdir, Kil
    grid_opt->addWidget( edit_bb,     1,3 );
 
     // third groupbox: figure environment
-   TQGroupBox *gb_fig= new TQGroupBox(2,Qt::Horizontal,i18n("Figure Environment"), plainPage());
+   TQGroupBox *gb_fig= new TQGroupBox(2,TQt::Horizontal,i18n("Figure Environment"), plainPage());
    TQWidget *widget_fig = new TQWidget(gb_fig);
    TQGridLayout *grid_fig = new TQGridLayout( widget_fig, 3,2, 6,6, "");
 
@@ -159,8 +159,8 @@ IncludeGraphics::IncludeGraphics(TQWidget *parent, const TQString &startdir, Kil
    updateFigure();
 
    // connect
-   connect( pb_choose, TQT_SIGNAL( clicked() ), this, TQT_SLOT( chooseFile() ) );
-   connect( cb_figure, TQT_SIGNAL(clicked()), this, TQT_SLOT(updateFigure() ) );
+   connect( pb_choose, TQ_SIGNAL( clicked() ), this, TQ_SLOT( chooseFile() ) );
+   connect( cb_figure, TQ_SIGNAL(clicked()), this, TQ_SLOT(updateFigure() ) );
 
    setFocusProxy( edit_file );
 }
@@ -410,12 +410,12 @@ void IncludeGraphics::execute(const TQString &command)
    m_proc->clearArguments();
    (*m_proc) << TQStringList::split(' ',command);
 
-   connect(m_proc, TQT_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
-           this, TQT_SLOT(slotProcessOutput(TDEProcess*,char*,int)) );
-   connect(m_proc, TQT_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
-           this, TQT_SLOT(slotProcessOutput(TDEProcess*,char*,int)) );
-   connect(m_proc, TQT_SIGNAL(processExited(TDEProcess*)),
-           this, TQT_SLOT(slotProcessExited(TDEProcess*)) );
+   connect(m_proc, TQ_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
+           this, TQ_SLOT(slotProcessOutput(TDEProcess*,char*,int)) );
+   connect(m_proc, TQ_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
+           this, TQ_SLOT(slotProcessOutput(TDEProcess*,char*,int)) );
+   connect(m_proc, TQ_SIGNAL(processExited(TDEProcess*)),
+           this, TQ_SLOT(slotProcessExited(TDEProcess*)) );
 
    m_output = "";
    KILE_DEBUG() << "=== IncludeGraphics::execute ====================" << endl;
