@@ -29,7 +29,7 @@
 
 class KileAbbrevView : public TDEListView  
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -68,7 +68,7 @@ private:
 
 class KileAbbrevInputDialog : public KDialogBase  
 {
-   Q_OBJECT
+   TQ_OBJECT
   
 
 public: 
