@@ -176,7 +176,7 @@ namespace KileTool
 	
 		//jump to first error
 		if ( nErrors > 0 && (readEntry("jumpToFirstError") == "yes") ) {
-			connect(this, TQT_SIGNAL(jumpToFirstError()), manager(), TQT_SIGNAL(jumpToFirstError()));
+			connect(this, TQ_SIGNAL(jumpToFirstError()), manager(), TQ_SIGNAL(jumpToFirstError()));
 			emit(jumpToFirstError());
 		}
 	}
